# Changelog

## [0.1.0-a4](https://github.com/gurobokum/liman/compare/liman_py-v0.1.0-a3...liman_py-v0.1.0-a4) (2025-08-19)


### ✨ Features

* **liman:** parse base_exception ([3e6786b](https://github.com/gurobokum/liman/commit/3e6786b13b4ba4ce6e5705f0eeca38db0737450d))


### 🐛 Bug Fixes

* issue with hardcoded dir for specs ([60f22ee](https://github.com/gurobokum/liman/commit/60f22ee72a3155bade9fb565f17ecf8cbdc93a11))
* **liman:** use asyncio.gather for python-3.10 support ([2989f97](https://github.com/gurobokum/liman/commit/2989f977bb7c5fe8c29f7062076f41d2f656d636))


### 📚 Documentation

* add 2 step in GettingStarted tutorial ([fc9dc1f](https://github.com/gurobokum/liman/commit/fc9dc1ffd9b82740d7e3c71c8d8754c0fc96f434))

## [0.1.0-a3](https://github.com/gurobokum/liman/compare/liman_py-v0.1.0-a2...liman_py-v0.1.0-a3) (2025-08-15)


### ✨ Features

* **liman:** implement __str__ for ExecutorOutput ([eaccf58](https://github.com/gurobokum/liman/commit/eaccf584cf300967fa7cd86c50a4b11dc279014c))
* **liman:** implement Agent class ([2233933](https://github.com/gurobokum/liman/commit/2233933b2bc5b0c4979d8a64a5964d3a4e70c462))
* **liman:** implement loader ([8d607d0](https://github.com/gurobokum/liman/commit/8d607d04d02f858ba1a68faba79062a230daeac0))


### 📚 Documentation

* **liman:** update README.md ([dc622c7](https://github.com/gurobokum/liman/commit/dc622c7206d1505333f2db5f457206a66dca7b51))
* **liman:** update README.md ([e4e3c33](https://github.com/gurobokum/liman/commit/e4e3c33007b9e7387f024fdd76d0e6f084fc3bb4))

## 0.1.0-a2 (2025-08-13)


### ✨ Features

* add protobuf ([f861ba3](https://github.com/gurobokum/liman/commit/f861ba3133d70ddc2ce083427c5b955a4f736d8f))
* **liman:** implement executor ([39d2b4e](https://github.com/gurobokum/liman/commit/39d2b4ec7b393e73e0b9dc1bc1bd981125df6928))


### 🛠 Code Refactoring

* drop protobuf ([baf82d3](https://github.com/gurobokum/liman/commit/baf82d36c7fe936895eef3e2ab2aa3be541796bd))
* **liman:** rework versioning ([b65a0ad](https://github.com/gurobokum/liman/commit/b65a0ad055fcf651e3bef501aaae3c4b8553ad54))
